# Simple database router.

Simple database router was originally written for personal and work purposes.

## Quick start

1. Add "django_auth_db_router" to your INSTALLED_APPS setting like this::
```
    INSTALLED_APPS = [
        ...
        'django_auth_db_router',
        ...
    ]
```
